functor NL_LexFun(structure Absyn: ABSYN
                           structure Tokens: NL__TOKENS
                              sharing type Absyn.set = Tokens.set 
                           structure Interface: INTERFACE) : LEXER  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof s = not (isSome (getc s))

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens
structure I = Interface
structure A = Absyn

open I

type pos = I.pos
type svalue = T.svalue
type ('a,'b) token = ('a,'b) T.token
type lexresult = (svalue,pos) token list * string

fun eof() = ([T.EOF(!line,!line)],"")

fun CNs s t       = ([T.CNs(A.ConS s,!line,!line)],t)
fun CNp s t       = ([T.CNp(A.ConS s,!line,!line)],t)
fun RNs s t       = ([T.RNs(A.ConR s,!line,!line)],t)
fun RNp s t       = ([T.RNp(A.ConR s,!line,!line)],t)
fun PN(s:string)  = ([T.PN(A.ConS s,!line,!line)],s)
fun IVs s t       = ([T.IVs(A.ConS s,!line,!line)],t)
fun IVp(s:string) = ([T.IVp(A.ConS s,!line,!line)],s)
fun TVs s t       = ([T.TVs(A.ConR s,!line,!line)],t)
fun TVp(s:string) = ([T.TVp(A.ConR s,!line,!line)],s)
fun CA(s:string)  = ([T.CA(A.ConS s,!line,!line)],s)
fun CAs s t       = ([T.CAs(A.ConS s,!line,!line)],t)
fun CAp s t       = ([T.CAp(A.ConS s,!line,!line)],t)
fun P(s:string)   = ([T.P(A.ConR s,!line,!line)],s)
fun IA s t        = ([T.IA(A.ConR s,!line,!line)],t)
fun IAcomp s t    = ([T.IAcomp(A.Tc(A.ConR s),!line,!line)],t)



      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[
([(#"\^@",#"\b",1),
(#"\v",#"\^_",1),
(#"!",#"-",1),
(#"/",#"@",1),
(#"C",#"C",1),
(#"G",#"G",1),
(#"L",#"L",1),
(#"O",#"Q",1),
(#"U",#"V",1),
(#"X",#"`",1),
(#"c",#"c",1),
(#"f",#"f",1),
(#"h",#"h",1),
(#"m",#"m",1),
(#"p",#"r",1),
(#"x",#"\194",1),
(#"\196",#"\255",1),
(#"\t",#"\t",2),
(#" ",#" ",2),
(#"\n",#"\n",3),
(#".",#".",4),
(#"A",#"A",5),
(#"B",#"B",6),
(#"D",#"D",7),
(#"E",#"E",8),
(#"F",#"F",9),
(#"H",#"H",10),
(#"I",#"I",11),
(#"J",#"J",12),
(#"K",#"K",13),
(#"M",#"M",14),
(#"N",#"N",15),
(#"R",#"R",16),
(#"S",#"S",17),
(#"T",#"T",18),
(#"W",#"W",19),
(#"a",#"a",20),
(#"b",#"b",21),
(#"d",#"d",22),
(#"e",#"e",23),
(#"g",#"g",24),
(#"i",#"i",25),
(#"j",#"j",26),
(#"k",#"k",27),
(#"l",#"l",28),
(#"n",#"n",29),
(#"o",#"o",30),
(#"s",#"s",31),
(#"t",#"t",32),
(#"u",#"u",33),
(#"v",#"v",34),
(#"w",#"w",35),
(#"\195",#"\195",36)], [0]), ([], [75]), ([(#"\t",#"\t",292),
(#" ",#" ",292)], [0, 75]), ([], [1]), ([], [2, 75]), ([(#"l",#"l",282),
(#"m",#"m",283),
(#"n",#"n",284)], [75]), ([(#"e",#"e",268),
(#"r",#"r",269)], [75]), ([(#"i",#"i",263)], [75]), ([(#"i",#"i",249),
(#"l",#"l",250),
(#"m",#"m",251)], [75]), ([(#"r",#"r",244)], [75]), ([(#"a",#"a",226),
(#"u",#"u",227)], [75]), ([(#"t",#"t",220)], [75]), ([(#"e",#"e",217)], [75]), ([(#"e",#"e",214)], [75]), ([(#"a",#"a",198),
(#"\195",#"\195",199)], [75]), ([(#"a",#"a",191)], [75]), ([(#"o",#"o",189)], [75]), ([(#"c",#"c",158),
(#"p",#"p",159),
(#"t",#"t",160)], [75]), ([(#"i",#"i",154)], [75]), ([(#"a",#"a",150)], [75]), ([(#"l",#"l",136),
(#"r",#"r",137)], [75]), ([(#"r",#"r",130)], [75]), ([(#"a",#"a",126),
(#"e",#"e",127),
(#"i",#"i",128)], [75]), ([(#"i",#"i",122)], [75]), ([(#"e",#"e",105),
(#"r",#"r",106)], [75]), ([(#"n",#"n",102),
(#"s",#"s",103)], [75]), ([(#"e",#"e",98)], [75]), ([(#"e",#"e",81),
(#"l",#"l",82)], [75]), ([(#"i",#"i",75)], [75]), ([(#"e",#"e",70)], [75]), ([(#"d",#"d",67)], [75]), ([(#"c",#"c",57),
(#"i",#"i",58)], [75]), ([(#"o",#"o",52)], [75]), ([(#"n",#"n",50)], [75]), ([(#"o",#"o",48)], [75]), ([(#"e",#"e",42)], [75]), ([(#"\164",#"\164",37)], [75]), ([(#"l",#"l",38)], []), ([(#"t",#"t",39)], []), ([(#"e",#"e",40)], []), ([(#"r",#"r",41)], []), ([], [63]), ([(#"i",#"i",43)], []), ([(#"\195",#"\195",44)], []), ([(#"\159",#"\159",45)], []), ([(#"e",#"e",46)], [52]), ([(#"r",#"s",47)], [53]), ([], [54]), ([(#"n",#"n",49)], []), ([], [5]), ([(#"d",#"d",51)], []), ([], [7]), ([(#"l",#"l",53)], []), ([(#"l",#"l",54)], []), ([(#"e",#"e",55)], [46]), ([(#"r",#"s",56)], [47]), ([], [48]), ([(#"h",#"h",61)], []), ([(#"n",#"n",59)], []), ([(#"d",#"d",60)], []), ([], [4]), ([(#"\195",#"\195",62)], []), ([(#"\182",#"\182",63)], []), ([(#"n",#"n",64)], []), ([(#"e",#"e",65)], []), ([(#"r",#"r",66)], []), ([], [62]), ([(#"e",#"e",68)], []), ([(#"r",#"r",69)], []), ([], [8]), ([(#"t",#"t",71)], []), ([(#"t",#"t",72)], []), ([(#"e",#"e",73)], [49]), ([(#"r",#"s",74)], [50]), ([], [51]), ([(#"e",#"e",76)], []), ([(#"b",#"b",77)], []), ([(#"e",#"e",78),
(#"t",#"t",79)], []), ([(#"n",#"n",80)], []), ([], [61]), ([], [60]), ([(#"i",#"i",89),
(#"n",#"n",90)], []), ([(#"e",#"e",83)], []), ([(#"i",#"i",84)], []), ([(#"n",#"n",85)], []), ([(#"e",#"e",86)], [68]), ([(#"r",#"r",87),
(#"s",#"s",88)], [68]), ([], [65, 68]), ([], [68]), ([(#"n",#"n",95)], []), ([(#"n",#"n",91)], []), ([(#"e",#"e",92),
(#"t",#"t",93)], []), ([(#"n",#"n",94)], []), ([], [59]), ([], [58]), ([(#"e",#"e",96)], [11]), ([(#"n",#"n",97),
(#"s",#"s",97)], [11]), ([], [11]), ([(#"d",#"d",99)], []), ([(#"e",#"e",100)], []), ([(#"n",#"n",101),
(#"r",#"s",101)], [12]), ([], [12]), ([], [55]), ([(#"t",#"t",104)], []), ([], [3]), ([(#"s",#"s",118)], []), ([(#"o",#"o",107),
(#"\195",#"\195",108)], []), ([(#"\195",#"\195",114)], []), ([(#"\182",#"\182",109)], []), ([(#"\195",#"\195",110)], []), ([(#"\159",#"\159",111)], []), ([(#"e",#"e",112)], []), ([(#"r",#"r",113)], []), ([], [64]), ([(#"\159",#"\159",115)], []), ([(#"e",#"e",116)], [67]), ([(#"r",#"s",117)], [67]), ([], [67]), ([(#"u",#"u",119)], []), ([(#"n",#"n",120)], []), ([(#"d",#"d",121)], []), ([], [42]), ([(#"n",#"n",123)], []), ([(#"e",#"e",124)], [10]), ([(#"n",#"n",125),
(#"s",#"s",125)], [10]), ([], [10]), ([(#"s",#"s",129)], []), ([(#"n",#"n",129),
(#"r",#"r",129)], []), ([(#"e",#"e",129)], []), ([], [9]), ([(#"a",#"a",131)], []), ([(#"u",#"u",132)], []), ([(#"n",#"n",133)], []), ([(#"e",#"e",134)], [43]), ([(#"r",#"s",135)], [44]), ([], [45]), ([(#"l",#"l",145),
(#"s",#"s",146),
(#"t",#"t",147)], []), ([(#"b",#"b",138)], []), ([(#"e",#"e",139)], []), ([(#"i",#"i",140)], []), ([(#"t",#"t",141)], []), ([(#"e",#"e",142)], []), ([(#"n",#"n",143),
(#"t",#"t",144)], []), ([], [56]), ([], [57]), ([(#"e",#"e",101)], []), ([], [6]), ([(#"e",#"e",148)], [66]), ([(#"r",#"s",149)], [66]), ([], [66]), ([(#"l",#"l",151)], []), ([(#"d",#"d",152)], []), ([(#"i",#"i",153)], []), ([], [17]), ([(#"e",#"e",155)], []), ([(#"r",#"r",156)], []), ([(#"e",#"e",157)], [73]), ([], [74]), ([(#"h",#"h",181)], []), ([(#"a",#"a",176)], []), ([(#"a",#"a",161),
(#"u",#"u",162),
(#"\195",#"\195",163)], []), ([(#"d",#"d",174)], []), ([(#"d",#"d",168)], []), ([(#"\164",#"\164",164)], []), ([(#"d",#"d",165)], []), ([(#"t",#"t",166)], []), ([(#"e",#"e",167)], []), ([], [41]), ([(#"e",#"e",169)], []), ([(#"n",#"n",170)], []), ([(#"t",#"t",171)], []), ([(#"e",#"e",172)], [30]), ([(#"n",#"n",173)], []), ([], [31]), ([(#"t",#"t",175)], []), ([], [40]), ([(#"n",#"n",177)], []), ([(#"i",#"i",178)], []), ([(#"e",#"e",179)], []), ([(#"n",#"n",180)], []), ([], [21]), ([(#"w",#"w",182)], []), ([(#"e",#"e",183)], []), ([(#"s",#"s",184)], []), ([(#"t",#"t",185)], []), ([(#"e",#"e",186)], []), ([(#"r",#"r",187)], []), ([(#"n",#"n",188)], [36]), ([], [37]), ([(#"m",#"m",190)], []), ([], [18]), ([(#"c",#"c",192)], []), ([(#"h",#"h",193)], []), ([(#"b",#"b",194)], []), ([(#"a",#"a",195)], []), ([(#"r",#"r",196)], []), ([(#"n",#"n",197)], [32]), ([], [33]), ([(#"d",#"d",205),
(#"n",#"n",206),
(#"r",#"r",207)], []), ([(#"\164",#"\164",200)], []), ([(#"n",#"n",201)], []), ([(#"n",#"n",202)], []), ([(#"e",#"e",203)], []), ([(#"r",#"r",204)], []), ([], [24]), ([(#"r",#"r",211)], []), ([(#"n",#"n",210)], []), ([(#"i",#"i",208)], []), ([(#"a",#"a",209)], []), ([], [16]), ([], [22]), ([(#"i",#"i",212)], []), ([(#"d",#"d",213)], []), ([], [19]), ([(#"i",#"i",215)], []), ([(#"n",#"n",216)], []), ([(#"e",#"e",97)], [11]), ([(#"d",#"d",218)], []), ([(#"e",#"e",219)], []), ([(#"n",#"n",101),
(#"r",#"r",101)], [12]), ([(#"a",#"a",221)], []), ([(#"l",#"l",222)], []), ([(#"i",#"i",223)], []), ([(#"e",#"e",224)], []), ([(#"n",#"n",225)], []), ([], [20]), ([(#"u",#"u",231)], []), ([(#"n",#"n",228)], []), ([(#"d",#"d",229)], []), ([(#"e",#"e",230)], [26]), ([], [27]), ([(#"p",#"p",232)], []), ([(#"t",#"t",233)], []), ([(#"s",#"s",234)], []), ([(#"t",#"t",235)], []), ([(#"a",#"a",236),
(#"\195",#"\195",237)], []), ([(#"d",#"d",242)], []), ([(#"\164",#"\164",238)], []), ([(#"d",#"d",239)], []), ([(#"t",#"t",240)], []), ([(#"e",#"e",241)], []), ([], [39]), ([(#"t",#"t",243)], []), ([], [38]), ([(#"a",#"a",245)], []), ([(#"u",#"u",246)], []), ([(#"e",#"e",247)], [23]), ([(#"n",#"n",248)], []), ([], [25]), ([(#"n",#"n",262)], []), ([(#"e",#"e",254)], []), ([(#"i",#"i",252)], []), ([(#"l",#"l",253)], []), ([], [15]), ([(#"p",#"p",255)], []), ([(#"h",#"h",256)], []), ([(#"a",#"a",257)], []), ([(#"n",#"n",258)], []), ([(#"t",#"t",259)], []), ([(#"e",#"e",260)], [71]), ([(#"n",#"n",261)], []), ([], [72]), ([(#"e",#"e",125)], [10]), ([(#"e",#"e",264)], []), ([(#"t",#"t",265)], []), ([(#"e",#"e",266)], []), ([(#"r",#"r",267)], []), ([], [14]), ([(#"r",#"r",279)], []), ([(#"u",#"u",270),
(#"\195",#"\195",271)], []), ([(#"d",#"d",276)], []), ([(#"\188",#"\188",272)], []), ([(#"d",#"d",273)], []), ([(#"e",#"e",274)], []), ([(#"r",#"r",275)], []), ([], [35]), ([(#"e",#"e",277)], []), ([(#"r",#"r",278)], []), ([], [34]), ([(#"g",#"g",280)], []), ([(#"e",#"e",281)], [28]), ([], [29]), ([(#"l",#"l",145)], []), ([(#"e",#"e",287)], []), ([(#"n",#"n",285)], []), ([(#"a",#"a",286)], []), ([], [13]), ([(#"i",#"i",288)], []), ([(#"s",#"s",289)], []), ([(#"e",#"e",290)], []), ([(#"n",#"n",291)], [69]), ([], [70]), ([(#"\t",#"\t",292),
(#" ",#" ",292)], [0])]

    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as ()) = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = (yystrm := strm; (lex()))
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      (next_line(); lex()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.PUNKT(!line,!line)],yytext)
      end
fun yyAction3 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVs(!line,!line)],yytext)
      end
fun yyAction4 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVp(!line,!line)],yytext)
      end
fun yyAction5 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.von(!line,!line)],yytext)
      end
fun yyAction6 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.als(!line,!line)],yytext)
      end
fun yyAction7 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.und(!line,!line)],yytext)
      end
fun yyAction8 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.oder(!line,!line)],yytext)
      end
fun yyAction9 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.DET(!line,!line)],yytext)
      end
fun yyAction10 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQ(!line,!line)],yytext)
      end
fun yyAction11 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQ(!line,!line)],yytext)
      end
fun yyAction12 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQ(!line,!line)],yytext)
      end
fun yyAction13 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Anna"))
fun yyAction14 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Dieter"))
fun yyAction15 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Emil"))
fun yyAction16 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Maria"))
fun yyAction17 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Waldi"))
fun yyAction18 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Rom"))
fun yyAction19 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Madrid"))
fun yyAction20 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Italien"))
fun yyAction21 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Spanien"))
fun yyAction22 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Mann" yytext)
      end
fun yyAction23 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Frau" yytext)
      end
fun yyAction24 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Mann" yytext)
      end
fun yyAction25 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Frau" yytext)
      end
fun yyAction26 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Hund" yytext)
      end
fun yyAction27 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Hund" yytext)
      end
fun yyAction28 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Berg" yytext)
      end
fun yyAction29 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Berg" yytext)
      end
fun yyAction30 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Student" yytext)
      end
fun yyAction31 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Student" yytext)
      end
fun yyAction32 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNs "Nachbar" yytext)
      end
fun yyAction33 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNp "Nachbar" yytext)
      end
fun yyAction34 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNs "Bruder" yytext)
      end
fun yyAction35 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNp "Bruder" yytext)
      end
fun yyAction36 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNs "Schwester" yytext)
      end
fun yyAction37 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNp "Schwester" yytext)
      end
fun yyAction38 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNs "Hauptstadt" yytext)
      end
fun yyAction39 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNp "Hauptstadt" yytext)
      end
fun yyAction40 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Stadt" yytext)
      end
fun yyAction41 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Stadt" yytext)
      end
fun yyAction42 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "gesund"))
fun yyAction43 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "braun"))
fun yyAction44 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAp "braun" yytext)
      end
fun yyAction45 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAs "braun" yytext)
      end
fun yyAction46 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "toll"))
fun yyAction47 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAp "toll" yytext)
      end
fun yyAction48 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAs "toll" yytext)
      end
fun yyAction49 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "nett"))
fun yyAction50 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAp "nett" yytext)
      end
fun yyAction51 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAs "nett" yytext)
      end
fun yyAction52 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "weiß"))
fun yyAction53 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        ([T.CAp(A.ConS "weiß",!line,!line),T.CAs(A.ConS "weiß",!line,!line)],yytext)
      end
fun yyAction54 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CAs "weiß" yytext)
      end
fun yyAction55 (strm, lastMatch : yymatch) = (yystrm := strm; (P "in"))
fun yyAction56 (strm, lastMatch : yymatch) = (yystrm := strm; (IVp "arbeiten"))
fun yyAction57 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IVs "arbeiten" yytext)
      end
fun yyAction58 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "kennen"))
fun yyAction59 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (TVs "kennen" yytext)
      end
fun yyAction60 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "lieben"))
fun yyAction61 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (TVs "lieben" yytext)
      end
fun yyAction62 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "schöner" yytext)
      end
fun yyAction63 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "älter" yytext)
      end
fun yyAction64 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "größer" yytext)
      end
fun yyAction65 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "kleiner" yytext)
      end
fun yyAction66 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "älter" yytext)
      end
fun yyAction67 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "größer" yytext)
      end
fun yyAction68 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "kleiner" yytext)
      end
fun yyAction69 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Ameise" yytext)
      end
fun yyAction70 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Ameise" yytext)
      end
fun yyAction71 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Elephant" yytext)
      end
fun yyAction72 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Elephant" yytext)
      end
fun yyAction73 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNs "Tier" yytext)
      end
fun yyAction74 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNp "Tier" yytext)
      end
fun yyAction75 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        (error ("ignoring illegal character " ^ yytext,
                      !line,!line); lex())
      end
val yyactTable = Vector.fromList([yyAction0, yyAction1, yyAction2, yyAction3,
  yyAction4, yyAction5, yyAction6, yyAction7, yyAction8, yyAction9, yyAction10,
  yyAction11, yyAction12, yyAction13, yyAction14, yyAction15, yyAction16,
  yyAction17, yyAction18, yyAction19, yyAction20, yyAction21, yyAction22,
  yyAction23, yyAction24, yyAction25, yyAction26, yyAction27, yyAction28,
  yyAction29, yyAction30, yyAction31, yyAction32, yyAction33, yyAction34,
  yyAction35, yyAction36, yyAction37, yyAction38, yyAction39, yyAction40,
  yyAction41, yyAction42, yyAction43, yyAction44, yyAction45, yyAction46,
  yyAction47, yyAction48, yyAction49, yyAction50, yyAction51, yyAction52,
  yyAction53, yyAction54, yyAction55, yyAction56, yyAction57, yyAction58,
  yyAction59, yyAction60, yyAction61, yyAction62, yyAction63, yyAction64,
  yyAction65, yyAction66, yyAction67, yyAction68, yyAction69, yyAction70,
  yyAction71, yyAction72, yyAction73, yyAction74, yyAction75])
in
  if yyInput.eof(!(yystrm))
    then UserDeclarations.eof(yyarg)
    else (case (!(yyss))
       of INITIAL => yygo yyactTable (0, !(yystrm), yyNO_MATCH)
      (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
