functor NL_LexFun(structure Absyn: ABSYN
                           structure Tokens: NL__TOKENS
                              sharing type Absyn.set = Tokens.set 
                           structure Interface: INTERFACE) : LEXER  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof s = not (isSome (getc s))

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens
structure I = Interface
structure A = Absyn

open I

type pos = I.pos
type svalue = T.svalue
type ('a,'b) token = ('a,'b) T.token
type lexresult = (svalue,pos) token list * string

fun eof() = ([T.EOF(!line,!line)],"")

fun PN(s:string) = ([T.PN(A.ConS s,!line,!line)],s)
fun CNn s t = ([T.CNn(A.ConS s,!line,!line)],t)
fun CNg s t = ([T.CNg(A.ConS s,!line,!line)],t)
fun CNd s t = ([T.CNd(A.ConS s,!line,!line)],t)
fun CNa s t = ([T.CNa(A.ConS s,!line,!line)],t)
fun RNsn s t = ([T.RNsn(A.ConR s,!line,!line)],t)
fun RNsg s t = ([T.RNsg(A.ConR s,!line,!line)],t)
fun RNsd s t = ([T.RNsd(A.ConR s,!line,!line)],t)
fun RNsa s t = ([T.RNsa(A.ConR s,!line,!line)],t)
fun RNpn s t = ([T.RNpn(A.ConR s,!line,!line)],t)
fun RNpg s t = ([T.RNpg(A.ConR s,!line,!line)],t)
fun RNpd s t = ([T.RNpd(A.ConR s,!line,!line)],t)
fun RNpa s t = ([T.RNpa(A.ConR s,!line,!line)],t)
fun IVs(s:string) = ([T.IVs(A.ConS s,!line,!line)],s)
fun IVp(s:string) = ([T.IVp(A.ConS s,!line,!line)],s)
fun TVs(s:string) = ([T.TVs(A.ConR s,!line,!line)],s)
fun TVp(s:string) = ([T.TVp(A.ConR s,!line,!line)],s)
fun CAsn(s:string) = ([T.CAsn(A.ConS s,!line,!line)],s)
fun CAsg(s:string) = ([T.CAsg(A.ConS s,!line,!line)],s)
fun CAsd(s:string) = ([T.CAsd(A.ConS s,!line,!line)],s)
fun CAsa(s:string) = ([T.CAsa(A.ConS s,!line,!line)],s)
fun CApn(s:string) = ([T.CApn(A.ConS s,!line,!line)],s)
fun CApg(s:string) = ([T.CApg(A.ConS s,!line,!line)],s)
fun CApd(s:string) = ([T.CApd(A.ConS s,!line,!line)],s)
fun CApa(s:string) = ([T.CApa(A.ConS s,!line,!line)],s)
fun P(s:string) = ([T.P(A.ConR s,!line,!line)],s)
fun IA s t        = ([T.IA(A.ConR s,!line,!line)],t)
fun IAcomp s t    = ([T.IAcomp(A.Tc(A.ConR s),!line,!line)],t)



      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[
([(#"\^@",#"\b",1),
(#"\v",#"\^_",1),
(#"!",#"-",1),
(#"/",#"@",1),
(#"C",#"C",1),
(#"G",#"G",1),
(#"L",#"L",1),
(#"O",#"Q",1),
(#"T",#"V",1),
(#"X",#"`",1),
(#"c",#"c",1),
(#"f",#"f",1),
(#"h",#"h",1),
(#"m",#"m",1),
(#"o",#"r",1),
(#"u",#"u",1),
(#"w",#"\194",1),
(#"\196",#"\255",1),
(#"\t",#"\t",2),
(#" ",#" ",2),
(#"\n",#"\n",3),
(#".",#".",4),
(#"A",#"A",5),
(#"B",#"B",6),
(#"D",#"D",7),
(#"E",#"E",8),
(#"F",#"F",9),
(#"H",#"H",10),
(#"I",#"I",11),
(#"J",#"J",12),
(#"K",#"K",13),
(#"M",#"M",14),
(#"N",#"N",15),
(#"R",#"R",16),
(#"S",#"S",17),
(#"W",#"W",18),
(#"a",#"a",19),
(#"b",#"b",20),
(#"d",#"d",21),
(#"e",#"e",22),
(#"g",#"g",23),
(#"i",#"i",24),
(#"j",#"j",25),
(#"k",#"k",26),
(#"l",#"l",27),
(#"n",#"n",28),
(#"s",#"s",29),
(#"t",#"t",30),
(#"v",#"v",31),
(#"\195",#"\195",32)], [0]), ([], [100]), ([(#"\t",#"\t",237),
(#" ",#" ",237)], [0, 100]), ([], [1]), ([], [2, 100]), ([(#"l",#"l",233),
(#"n",#"n",234)], [100]), ([(#"r",#"r",227)], [100]), ([(#"i",#"i",222)], [100]), ([(#"i",#"i",105),
(#"m",#"m",219)], [100]), ([(#"r",#"r",216)], [100]), ([(#"a",#"a",202),
(#"u",#"u",203)], [100]), ([(#"t",#"t",196)], [100]), ([(#"e",#"e",191)], [100]), ([(#"e",#"e",190)], [100]), ([(#"a",#"a",178)], [100]), ([(#"a",#"a",170)], [100]), ([(#"o",#"o",168)], [100]), ([(#"c",#"c",146),
(#"p",#"p",147),
(#"t",#"t",148)], [100]), ([(#"a",#"a",142)], [100]), ([(#"l",#"l",129),
(#"r",#"r",130)], [100]), ([(#"r",#"r",120)], [100]), ([(#"a",#"a",112),
(#"e",#"e",113),
(#"i",#"i",114)], [100]), ([(#"i",#"i",105)], [100]), ([(#"e",#"e",100)], [100]), ([(#"n",#"n",97),
(#"s",#"s",98)], [100]), ([(#"e",#"e",91)], [100]), ([(#"e",#"e",78)], [100]), ([(#"i",#"i",72)], [100]), ([(#"e",#"e",64)], [100]), ([(#"c",#"c",54),
(#"i",#"i",55)], [100]), ([(#"a",#"a",40),
(#"o",#"o",41)], [100]), ([(#"o",#"o",38)], [100]), ([(#"\164",#"\164",33)], [100]), ([(#"l",#"l",34)], []), ([(#"t",#"t",35)], []), ([(#"e",#"e",36)], []), ([(#"r",#"r",37)], []), ([], [90]), ([(#"n",#"n",39)], []), ([], [5]), ([(#"n",#"n",49)], []), ([(#"l",#"l",42)], []), ([(#"l",#"l",43)], []), ([(#"e",#"e",44)], []), ([(#"m",#"m",45),
(#"n",#"n",46),
(#"r",#"r",47),
(#"s",#"s",48)], [73, 76, 77, 80]), ([], [75]), ([], [74, 76, 79]), ([], [73, 74, 75, 78]), ([], [73, 76]), ([(#"z",#"z",50)], []), ([(#"e",#"e",51),
(#"t",#"t",52)], []), ([(#"n",#"n",53)], []), ([], [99]), ([], [98]), ([(#"h",#"h",58)], []), ([(#"n",#"n",56)], []), ([(#"d",#"d",57)], []), ([], [4]), ([(#"\195",#"\195",59)], []), ([(#"\182",#"\182",60)], []), ([(#"n",#"n",61)], []), ([(#"e",#"e",62)], []), ([(#"r",#"r",63)], []), ([], [89]), ([(#"t",#"t",65)], []), ([(#"t",#"t",66)], []), ([(#"e",#"e",67)], []), ([(#"m",#"m",68),
(#"n",#"n",69),
(#"r",#"r",70),
(#"s",#"s",71)], [81, 84, 85, 88]), ([], [83]), ([], [82, 84, 87]), ([], [81, 82, 83, 86]), ([], [81, 84]), ([(#"e",#"e",73)], []), ([(#"b",#"b",74)], []), ([(#"e",#"e",75),
(#"t",#"t",76)], []), ([(#"n",#"n",77)], []), ([], [97]), ([], [96]), ([(#"i",#"i",79),
(#"n",#"n",80)], []), ([(#"n",#"n",85)], []), ([(#"n",#"n",81)], []), ([(#"e",#"e",82),
(#"t",#"t",83)], []), ([(#"n",#"n",84)], []), ([], [95]), ([], [94]), ([(#"e",#"e",86)], [15, 18]), ([(#"m",#"m",87),
(#"n",#"n",88),
(#"r",#"r",89),
(#"s",#"s",90)], [15, 18]), ([], [17]), ([], [18]), ([], [16, 17]), ([], [16]), ([(#"d",#"d",92)], []), ([(#"e",#"e",93)], []), ([(#"m",#"m",94),
(#"r",#"r",95),
(#"s",#"s",96)], [19, 22]), ([], [21]), ([], [19, 20, 21, 22]), ([], [19, 20, 22]), ([], [91]), ([(#"t",#"t",99)], []), ([], [3]), ([(#"s",#"s",101)], []), ([(#"u",#"u",102)], []), ([(#"n",#"n",103)], []), ([(#"d",#"d",104)], []), ([], [64]), ([(#"n",#"n",106)], []), ([(#"e",#"e",107)], [11, 14]), ([(#"m",#"m",108),
(#"n",#"n",109),
(#"r",#"r",110),
(#"s",#"s",111)], [11, 14]), ([], [13]), ([], [14]), ([], [12, 13]), ([], [12]), ([(#"s",#"s",115)], []), ([(#"m",#"m",116),
(#"n",#"n",117),
(#"r",#"r",118),
(#"s",#"s",119)], []), ([(#"e",#"e",115)], []), ([], [7, 10]), ([], [9]), ([], [10]), ([], [7, 8, 9]), ([], [8]), ([(#"a",#"a",121)], []), ([(#"u",#"u",122)], []), ([(#"n",#"n",123)], []), ([(#"e",#"e",124)], []), ([(#"m",#"m",125),
(#"n",#"n",126),
(#"r",#"r",127),
(#"s",#"s",128)], [65, 68, 69, 72]), ([], [67]), ([], [66, 68, 71]), ([], [65, 66, 67, 70]), ([], [65, 68]), ([(#"l",#"l",138),
(#"s",#"s",139)], []), ([(#"b",#"b",131)], []), ([(#"e",#"e",132)], []), ([(#"i",#"i",133)], []), ([(#"t",#"t",134)], []), ([(#"e",#"e",135)], []), ([(#"n",#"n",136),
(#"t",#"t",137)], []), ([], [92]), ([], [93]), ([(#"e",#"e",140)], []), ([], [6]), ([(#"n",#"n",94),
(#"r",#"r",141)], [19, 22]), ([], [20]), ([(#"l",#"l",143)], []), ([(#"d",#"d",144)], []), ([(#"i",#"i",145)], []), ([], [27]), ([(#"h",#"h",161)], []), ([(#"a",#"a",156)], []), ([(#"u",#"u",149)], []), ([(#"d",#"d",150)], []), ([(#"e",#"e",151)], []), ([(#"n",#"n",152)], []), ([(#"t",#"t",153)], []), ([(#"e",#"e",154)], [44]), ([(#"n",#"n",155)], []), ([], [45, 46, 47]), ([(#"n",#"n",157)], []), ([(#"i",#"i",158)], []), ([(#"e",#"e",159)], []), ([(#"n",#"n",160)], []), ([], [31]), ([(#"w",#"w",162)], []), ([(#"e",#"e",163)], []), ([(#"s",#"s",164)], []), ([(#"t",#"t",165)], []), ([(#"e",#"e",166)], []), ([(#"r",#"r",167)], []), ([], [52, 53, 54, 55]), ([(#"m",#"m",169)], []), ([], [28]), ([(#"c",#"c",171)], []), ([(#"h",#"h",172)], []), ([(#"b",#"b",173)], []), ([(#"a",#"a",174)], []), ([(#"r",#"r",175)], []), ([(#"n",#"n",176),
(#"s",#"s",177)], [56]), ([], [58, 59]), ([], [57]), ([(#"d",#"d",179),
(#"n",#"n",180),
(#"r",#"r",181)], []), ([(#"r",#"r",187)], []), ([(#"n",#"n",184)], []), ([(#"i",#"i",182)], []), ([(#"a",#"a",183)], []), ([], [26]), ([(#"e",#"e",185)], [32, 34, 35]), ([(#"s",#"s",186)], []), ([], [33]), ([(#"i",#"i",188)], []), ([(#"d",#"d",189)], []), ([], [29]), ([(#"i",#"i",79)], []), ([(#"d",#"d",192)], []), ([(#"e",#"e",193)], []), ([(#"m",#"m",94),
(#"n",#"n",194),
(#"r",#"r",195),
(#"s",#"s",96)], [19, 22]), ([], [22]), ([], [19, 20, 21]), ([(#"a",#"a",197)], []), ([(#"l",#"l",198)], []), ([(#"i",#"i",199)], []), ([(#"e",#"e",200)], []), ([(#"n",#"n",201)], []), ([], [30]), ([(#"u",#"u",208)], []), ([(#"n",#"n",204)], []), ([(#"d",#"d",205)], []), ([(#"e",#"e",206)], [40, 42, 43]), ([(#"s",#"s",207)], []), ([], [41]), ([(#"p",#"p",209)], []), ([(#"t",#"t",210)], []), ([(#"s",#"s",211)], []), ([(#"t",#"t",212)], []), ([(#"a",#"a",213)], []), ([(#"d",#"d",214)], []), ([(#"t",#"t",215)], []), ([], [60, 61, 62, 63]), ([(#"a",#"a",217)], []), ([(#"u",#"u",218)], []), ([], [36, 37, 38, 39]), ([(#"i",#"i",220)], []), ([(#"l",#"l",221)], []), ([], [25]), ([(#"e",#"e",223)], []), ([(#"t",#"t",224)], []), ([(#"e",#"e",225)], []), ([(#"r",#"r",226)], []), ([], [24]), ([(#"u",#"u",228)], []), ([(#"d",#"d",229)], []), ([(#"e",#"e",230)], []), ([(#"r",#"r",231)], []), ([(#"s",#"s",232)], [48, 50, 51]), ([], [49]), ([(#"l",#"l",138)], []), ([(#"n",#"n",235)], []), ([(#"a",#"a",236)], []), ([], [23]), ([(#"\t",#"\t",237),
(#" ",#" ",237)], [0])]

    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as ()) = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = (yystrm := strm; (lex()))
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      (next_line(); lex()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.PUNKT(!line,!line)],yytext)
      end
fun yyAction3 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVs(!line,!line)],yytext)
      end
fun yyAction4 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVp(!line,!line)],yytext)
      end
fun yyAction5 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.von(!line,!line)],yytext)
      end
fun yyAction6 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.als(!line,!line)],yytext)
      end
fun yyAction7 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.DETn(!line,!line)],yytext)
      end
fun yyAction8 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.DETg(!line,!line)],yytext)
      end
fun yyAction9 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.DETd(!line,!line)],yytext)
      end
fun yyAction10 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.DETa(!line,!line)],yytext)
      end
fun yyAction11 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQn(!line,!line)],yytext)
      end
fun yyAction12 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQg(!line,!line)],yytext)
      end
fun yyAction13 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQd(!line,!line)],yytext)
      end
fun yyAction14 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQa(!line,!line)],yytext)
      end
fun yyAction15 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQn(!line,!line)],yytext)
      end
fun yyAction16 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQg(!line,!line)],yytext)
      end
fun yyAction17 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQd(!line,!line)],yytext)
      end
fun yyAction18 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQa(!line,!line)],yytext)
      end
fun yyAction19 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQn(!line,!line)],yytext)
      end
fun yyAction20 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQg(!line,!line)],yytext)
      end
fun yyAction21 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQd(!line,!line)],yytext)
      end
fun yyAction22 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQa(!line,!line)],yytext)
      end
fun yyAction23 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Anna"))
fun yyAction24 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Dieter"))
fun yyAction25 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Emil"))
fun yyAction26 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Maria"))
fun yyAction27 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Waldi"))
fun yyAction28 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Rom"))
fun yyAction29 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Madrid"))
fun yyAction30 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Italien"))
fun yyAction31 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Spanien"))
fun yyAction32 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Mann" yytext)
      end
fun yyAction33 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Mann" yytext)
      end
fun yyAction34 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Mann" yytext)
      end
fun yyAction35 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Mann" yytext)
      end
fun yyAction36 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Frau" yytext)
      end
fun yyAction37 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Frau" yytext)
      end
fun yyAction38 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Frau" yytext)
      end
fun yyAction39 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Frau" yytext)
      end
fun yyAction40 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Hund" yytext)
      end
fun yyAction41 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Hund" yytext)
      end
fun yyAction42 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Hund" yytext)
      end
fun yyAction43 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Hund" yytext)
      end
fun yyAction44 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Student" yytext)
      end
fun yyAction45 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Student" yytext)
      end
fun yyAction46 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Student" yytext)
      end
fun yyAction47 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Student" yytext)
      end
fun yyAction48 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Bruder" yytext)
      end
fun yyAction49 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Bruder" yytext)
      end
fun yyAction50 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Bruder" yytext)
      end
fun yyAction51 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Bruder" yytext)
      end
fun yyAction52 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Schwester" yytext)
      end
fun yyAction53 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Schwester" yytext)
      end
fun yyAction54 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Schwester" yytext)
      end
fun yyAction55 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Schwester" yytext)
      end
fun yyAction56 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Nachbar" yytext)
      end
fun yyAction57 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Nachbar" yytext)
      end
fun yyAction58 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Nachbar" yytext)
      end
fun yyAction59 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Nachbar" yytext)
      end
fun yyAction60 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Hauptstadt" yytext)
      end
fun yyAction61 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Hauptstadt" yytext)
      end
fun yyAction62 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Hauptstadt" yytext)
      end
fun yyAction63 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Hauptstadt" yytext)
      end
fun yyAction64 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "gesund"))
fun yyAction65 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "braun"))
fun yyAction66 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsg "braun"))
fun yyAction67 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsd "braun"))
fun yyAction68 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsa "braun"))
fun yyAction69 (strm, lastMatch : yymatch) = (yystrm := strm; (CApn "braun"))
fun yyAction70 (strm, lastMatch : yymatch) = (yystrm := strm; (CApg "braun"))
fun yyAction71 (strm, lastMatch : yymatch) = (yystrm := strm; (CApd "braun"))
fun yyAction72 (strm, lastMatch : yymatch) = (yystrm := strm; (CApa "braun"))
fun yyAction73 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "toll"))
fun yyAction74 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsg "toll"))
fun yyAction75 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsd "toll"))
fun yyAction76 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsa "toll"))
fun yyAction77 (strm, lastMatch : yymatch) = (yystrm := strm; (CApn "toll"))
fun yyAction78 (strm, lastMatch : yymatch) = (yystrm := strm; (CApg "toll"))
fun yyAction79 (strm, lastMatch : yymatch) = (yystrm := strm; (CApd "toll"))
fun yyAction80 (strm, lastMatch : yymatch) = (yystrm := strm; (CApa "toll"))
fun yyAction81 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "nett"))
fun yyAction82 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsg "nett"))
fun yyAction83 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsd "nett"))
fun yyAction84 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsa "nett"))
fun yyAction85 (strm, lastMatch : yymatch) = (yystrm := strm; (CApn "nett"))
fun yyAction86 (strm, lastMatch : yymatch) = (yystrm := strm; (CApg "nett"))
fun yyAction87 (strm, lastMatch : yymatch) = (yystrm := strm; (CApd "nett"))
fun yyAction88 (strm, lastMatch : yymatch) = (yystrm := strm; (CApa "nett"))
fun yyAction89 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "schöner" yytext)
      end
fun yyAction90 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "älter" yytext)
      end
fun yyAction91 (strm, lastMatch : yymatch) = (yystrm := strm; (P "in"))
fun yyAction92 (strm, lastMatch : yymatch) = (yystrm := strm; (IVp "arbeiten"))
fun yyAction93 (strm, lastMatch : yymatch) = (yystrm := strm; (IVs "arbeiten"))
fun yyAction94 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "kennen"))
fun yyAction95 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "kennen"))
fun yyAction96 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "lieben"))
fun yyAction97 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "lieben"))
fun yyAction98 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "tanzen"))
fun yyAction99 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "tanzen"))
fun yyAction100 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        (error ("ignoring illegal character " ^ yytext,
                      !line,!line); lex())
      end
val yyactTable = Vector.fromList([yyAction0, yyAction1, yyAction2, yyAction3,
  yyAction4, yyAction5, yyAction6, yyAction7, yyAction8, yyAction9, yyAction10,
  yyAction11, yyAction12, yyAction13, yyAction14, yyAction15, yyAction16,
  yyAction17, yyAction18, yyAction19, yyAction20, yyAction21, yyAction22,
  yyAction23, yyAction24, yyAction25, yyAction26, yyAction27, yyAction28,
  yyAction29, yyAction30, yyAction31, yyAction32, yyAction33, yyAction34,
  yyAction35, yyAction36, yyAction37, yyAction38, yyAction39, yyAction40,
  yyAction41, yyAction42, yyAction43, yyAction44, yyAction45, yyAction46,
  yyAction47, yyAction48, yyAction49, yyAction50, yyAction51, yyAction52,
  yyAction53, yyAction54, yyAction55, yyAction56, yyAction57, yyAction58,
  yyAction59, yyAction60, yyAction61, yyAction62, yyAction63, yyAction64,
  yyAction65, yyAction66, yyAction67, yyAction68, yyAction69, yyAction70,
  yyAction71, yyAction72, yyAction73, yyAction74, yyAction75, yyAction76,
  yyAction77, yyAction78, yyAction79, yyAction80, yyAction81, yyAction82,
  yyAction83, yyAction84, yyAction85, yyAction86, yyAction87, yyAction88,
  yyAction89, yyAction90, yyAction91, yyAction92, yyAction93, yyAction94,
  yyAction95, yyAction96, yyAction97, yyAction98, yyAction99, yyAction100])
in
  if yyInput.eof(!(yystrm))
    then UserDeclarations.eof(yyarg)
    else (case (!(yyss))
       of INITIAL => yygo yyactTable (0, !(yystrm), yyNO_MATCH)
      (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
