functor NL_LexFun(structure Absyn: ABSYN
                           structure Tokens: NL__TOKENS
                              sharing type Absyn.set = Tokens.set 
                           structure Interface: INTERFACE) : LEXER  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof s = not (isSome (getc s))

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens
structure I = Interface
structure A = Absyn

open I

type pos = I.pos
type svalue = T.svalue
type ('a,'b) token = ('a,'b) T.token
type lexresult = (svalue,pos) token list * string

fun eof() = ([T.EOF(!line,!line)],"")

fun CN s t       = ([T.CN(A.ConS s,!line,!line)],t)
fun RN s t       = ([T.RN(A.ConR s,!line,!line)],t)
fun PN(s:string) = ([T.PN(A.ConS s,!line,!line)],s)
fun IV s t       = ([T.IV(A.ConS s,!line,!line)],t)
fun TV(s:string) = ([T.TV(A.ConR s,!line,!line)],s)
fun CA(s:string) = ([T.CA(A.ConS s,!line,!line)],s)
fun P(s:string) = ([T.P(A.ConR s,!line,!line)],s)
fun IA s t       = ([T.IA(A.ConR s,!line,!line)],t)
fun IAcomp s t   = ([T.IAcomp(A.Tc(A.ConR s),!line,!line)],t)



      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[
([(#"\^@",#"\b",1),
(#"\v",#"\^_",1),
(#"!",#"-",1),
(#"/",#"@",1),
(#"C",#"C",1),
(#"G",#"G",1),
(#"L",#"L",1),
(#"O",#"Q",1),
(#"U",#"V",1),
(#"X",#"`",1),
(#"c",#"c",1),
(#"f",#"f",1),
(#"h",#"h",1),
(#"m",#"m",1),
(#"p",#"r",1),
(#"x",#"\194",1),
(#"\196",#"\255",1),
(#"\t",#"\t",2),
(#" ",#" ",2),
(#"\n",#"\n",3),
(#".",#".",4),
(#"A",#"A",5),
(#"B",#"B",6),
(#"D",#"D",7),
(#"E",#"E",8),
(#"F",#"F",9),
(#"H",#"H",10),
(#"I",#"I",11),
(#"J",#"J",12),
(#"j",#"j",12),
(#"K",#"K",13),
(#"M",#"M",14),
(#"N",#"N",15),
(#"R",#"R",16),
(#"S",#"S",17),
(#"T",#"T",18),
(#"W",#"W",19),
(#"a",#"a",20),
(#"b",#"b",21),
(#"d",#"d",22),
(#"e",#"e",23),
(#"g",#"g",24),
(#"i",#"i",25),
(#"k",#"k",26),
(#"l",#"l",27),
(#"n",#"n",28),
(#"o",#"o",29),
(#"s",#"s",30),
(#"t",#"t",31),
(#"u",#"u",32),
(#"v",#"v",33),
(#"w",#"w",34),
(#"\195",#"\195",35)], [0]), ([], [54]), ([(#"\t",#"\t",256),
(#" ",#" ",256)], [0, 54]), ([], [1]), ([], [2, 54]), ([(#"l",#"l",246),
(#"m",#"m",247),
(#"n",#"n",248)], [54]), ([(#"e",#"e",238),
(#"r",#"r",239)], [54]), ([(#"i",#"i",233)], [54]), ([(#"i",#"i",219),
(#"l",#"l",220),
(#"m",#"m",221)], [54]), ([(#"r",#"r",216)], [54]), ([(#"a",#"a",203),
(#"u",#"u",204)], [54]), ([(#"t",#"t",197)], [54]), ([(#"e",#"e",194)], [54]), ([(#"e",#"e",191)], [54]), ([(#"a",#"a",181)], [54]), ([(#"a",#"a",175)], [54]), ([(#"o",#"o",173)], [54]), ([(#"c",#"c",148),
(#"p",#"p",149),
(#"t",#"t",150)], [54]), ([(#"i",#"i",144)], [54]), ([(#"a",#"a",140)], [54]), ([(#"l",#"l",126),
(#"r",#"r",127)], [54]), ([(#"r",#"r",120)], [54]), ([(#"a",#"a",116),
(#"e",#"e",117),
(#"i",#"i",118)], [54]), ([(#"i",#"i",112)], [54]), ([(#"e",#"e",95),
(#"r",#"r",96)], [54]), ([(#"n",#"n",92),
(#"s",#"s",93)], [54]), ([(#"e",#"e",76),
(#"l",#"l",77)], [54]), ([(#"i",#"i",71)], [54]), ([(#"e",#"e",66)], [54]), ([(#"d",#"d",63)], [54]), ([(#"c",#"c",56)], [54]), ([(#"o",#"o",51)], [54]), ([(#"n",#"n",49)], [54]), ([(#"o",#"o",47)], [54]), ([(#"e",#"e",41)], [54]), ([(#"\164",#"\164",36)], [54]), ([(#"l",#"l",37)], []), ([(#"t",#"t",38)], []), ([(#"e",#"e",39)], []), ([(#"r",#"r",40)], []), ([], [38, 44]), ([(#"i",#"i",42)], []), ([(#"\195",#"\195",43)], []), ([(#"\159",#"\159",44)], []), ([(#"e",#"e",45)], []), ([(#"r",#"s",46)], [32]), ([], [32]), ([(#"n",#"n",48)], []), ([], [4]), ([(#"d",#"d",50)], []), ([], [6]), ([(#"l",#"l",52)], []), ([(#"l",#"l",53)], []), ([(#"e",#"e",54)], [34]), ([(#"r",#"r",55)], [34]), ([], [34]), ([(#"h",#"h",57)], []), ([(#"\195",#"\195",58)], []), ([(#"\182",#"\182",59)], []), ([(#"n",#"n",60)], []), ([(#"e",#"e",61)], [36]), ([(#"r",#"r",62)], []), ([], [37, 43]), ([(#"e",#"e",64)], []), ([(#"r",#"r",65)], []), ([], [7]), ([(#"t",#"t",67)], []), ([(#"t",#"t",68)], []), ([(#"e",#"e",69)], [35]), ([(#"n",#"n",70),
(#"r",#"r",70)], [35]), ([], [35]), ([(#"e",#"e",72)], []), ([(#"b",#"b",73)], []), ([(#"e",#"e",74),
(#"t",#"t",75)], []), ([(#"n",#"n",75)], []), ([], [42]), ([(#"i",#"i",84),
(#"n",#"n",85)], []), ([(#"e",#"e",78)], []), ([(#"i",#"i",79)], []), ([(#"n",#"n",80)], []), ([(#"e",#"e",81)], [49]), ([(#"r",#"r",82),
(#"s",#"s",83)], [49]), ([], [46, 49]), ([], [49]), ([(#"n",#"n",89)], []), ([(#"n",#"n",86)], []), ([(#"e",#"e",87),
(#"t",#"t",88)], []), ([(#"n",#"n",88)], []), ([], [41]), ([(#"e",#"e",90)], [10]), ([(#"n",#"n",91),
(#"s",#"s",91)], [10]), ([], [10]), ([], [39]), ([(#"t",#"t",94)], []), ([], [3]), ([(#"s",#"s",108)], []), ([(#"o",#"o",97),
(#"\195",#"\195",98)], []), ([(#"\195",#"\195",104)], []), ([(#"\182",#"\182",99)], []), ([(#"\195",#"\195",100)], []), ([(#"\159",#"\159",101)], []), ([(#"e",#"e",102)], []), ([(#"r",#"r",103)], []), ([], [45]), ([(#"\159",#"\159",105)], []), ([(#"e",#"e",106)], [48]), ([(#"r",#"s",107)], [48]), ([], [48]), ([(#"u",#"u",109)], []), ([(#"n",#"n",110)], []), ([(#"d",#"d",111)], []), ([], [31]), ([(#"n",#"n",113)], []), ([(#"e",#"e",114)], [9]), ([(#"n",#"n",115),
(#"s",#"s",115)], [9]), ([], [9]), ([(#"s",#"s",119)], []), ([(#"n",#"n",119),
(#"r",#"r",119)], []), ([(#"e",#"e",119)], []), ([], [8]), ([(#"a",#"a",121)], []), ([(#"u",#"u",122)], []), ([(#"n",#"n",123)], []), ([(#"e",#"e",124)], [33]), ([(#"r",#"r",125)], [33]), ([], [33]), ([(#"l",#"l",134),
(#"s",#"s",135),
(#"t",#"t",136)], []), ([(#"b",#"b",128)], []), ([(#"e",#"e",129)], []), ([(#"i",#"i",130)], []), ([(#"t",#"t",131)], []), ([(#"e",#"e",132)], []), ([(#"n",#"n",133),
(#"t",#"t",133)], []), ([], [40]), ([(#"e",#"e",139)], []), ([], [5]), ([(#"e",#"e",137)], [47]), ([(#"r",#"s",138)], [47]), ([], [47]), ([], [11]), ([(#"l",#"l",141)], []), ([(#"d",#"d",142)], []), ([(#"i",#"i",143)], []), ([], [16]), ([(#"e",#"e",145)], []), ([(#"r",#"r",146)], []), ([(#"e",#"e",147)], [53]), ([], [53]), ([(#"h",#"h",166)], []), ([(#"a",#"a",161)], []), ([(#"a",#"a",151),
(#"u",#"u",152)], []), ([(#"d",#"d",159)], []), ([(#"d",#"d",153)], []), ([(#"e",#"e",154)], []), ([(#"n",#"n",155)], []), ([(#"t",#"t",156)], []), ([(#"e",#"e",157)], [25]), ([(#"n",#"n",158)], []), ([], [25]), ([(#"t",#"t",160)], []), ([], [30]), ([(#"n",#"n",162)], []), ([(#"i",#"i",163)], []), ([(#"e",#"e",164)], []), ([(#"n",#"n",165)], []), ([], [20]), ([(#"w",#"w",167)], []), ([(#"e",#"e",168)], []), ([(#"s",#"s",169)], []), ([(#"t",#"t",170)], []), ([(#"e",#"e",171)], []), ([(#"r",#"r",172)], []), ([], [28]), ([(#"m",#"m",174)], []), ([], [17]), ([(#"c",#"c",176)], []), ([(#"h",#"h",177)], []), ([(#"b",#"b",178)], []), ([(#"a",#"a",179)], []), ([(#"r",#"r",180)], []), ([], [26]), ([(#"d",#"d",182),
(#"n",#"n",183),
(#"r",#"r",184)], []), ([(#"r",#"r",188)], []), ([(#"n",#"n",187)], []), ([(#"i",#"i",185)], []), ([(#"a",#"a",186)], []), ([], [15]), ([], [21]), ([(#"i",#"i",189)], []), ([(#"d",#"d",190)], []), ([], [18]), ([(#"i",#"i",192)], []), ([(#"n",#"n",193)], []), ([(#"e",#"e",91)], [10]), ([(#"d",#"d",195)], []), ([(#"e",#"e",196)], []), ([(#"n",#"n",139),
(#"r",#"r",139)], [11]), ([(#"a",#"a",198)], []), ([(#"l",#"l",199)], []), ([(#"i",#"i",200)], []), ([(#"e",#"e",201)], []), ([(#"n",#"n",202)], []), ([], [19]), ([(#"u",#"u",208)], []), ([(#"n",#"n",205)], []), ([(#"d",#"d",206)], []), ([(#"e",#"e",207)], [23, 51]), ([], [23, 51]), ([(#"p",#"p",209)], []), ([(#"t",#"t",210)], []), ([(#"s",#"s",211)], []), ([(#"t",#"t",212)], []), ([(#"a",#"a",213)], []), ([(#"d",#"d",214)], []), ([(#"t",#"t",215)], []), ([], [29]), ([(#"a",#"a",217)], []), ([(#"u",#"u",218)], []), ([], [22]), ([(#"n",#"n",232)], []), ([(#"e",#"e",224)], []), ([(#"i",#"i",222)], []), ([(#"l",#"l",223)], []), ([], [14]), ([(#"p",#"p",225)], []), ([(#"h",#"h",226)], []), ([(#"a",#"a",227)], []), ([(#"n",#"n",228)], []), ([(#"t",#"t",229)], []), ([(#"e",#"e",230)], [52]), ([(#"n",#"n",231)], []), ([], [52]), ([(#"e",#"e",115)], [9]), ([(#"e",#"e",234)], []), ([(#"t",#"t",235)], []), ([(#"e",#"e",236)], []), ([(#"r",#"r",237)], []), ([], [13]), ([(#"r",#"r",244)], []), ([(#"u",#"u",240)], []), ([(#"d",#"d",241)], []), ([(#"e",#"e",242)], []), ([(#"r",#"r",243)], []), ([], [27]), ([(#"g",#"g",245)], []), ([], [24]), ([(#"l",#"l",134)], []), ([(#"e",#"e",251)], []), ([(#"n",#"n",249)], []), ([(#"a",#"a",250)], []), ([], [12]), ([(#"i",#"i",252)], []), ([(#"s",#"s",253)], []), ([(#"e",#"e",254)], []), ([(#"n",#"n",255)], [50]), ([], [50]), ([(#"\t",#"\t",256),
(#" ",#" ",256)], [0])]

    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as ()) = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = (yystrm := strm; (lex()))
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      (next_line(); lex()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.PUNKT(!line,!line)],yytext)
      end
fun yyAction3 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopV(!line,!line)],yytext)
      end
fun yyAction4 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.von(!line,!line)],yytext)
      end
fun yyAction5 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.als(!line,!line)],yytext)
      end
fun yyAction6 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.und(!line,!line)],yytext)
      end
fun yyAction7 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.oder(!line,!line)],yytext)
      end
fun yyAction8 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Det(!line,!line)],yytext)
      end
fun yyAction9 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQ(!line,!line)],yytext)
      end
fun yyAction10 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQ(!line,!line)],yytext)
      end
fun yyAction11 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQ(!line,!line)],yytext)
      end
fun yyAction12 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Anna"))
fun yyAction13 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Dieter"))
fun yyAction14 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Emil"))
fun yyAction15 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Maria"))
fun yyAction16 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Waldi"))
fun yyAction17 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Rom"))
fun yyAction18 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Madrid"))
fun yyAction19 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Italien"))
fun yyAction20 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Spanien"))
fun yyAction21 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Mann" yytext)
      end
fun yyAction22 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Frau" yytext)
      end
fun yyAction23 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Hund" yytext)
      end
fun yyAction24 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Berg" yytext)
      end
fun yyAction25 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Student" yytext)
      end
fun yyAction26 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RN "Nachbar" yytext)
      end
fun yyAction27 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RN "Bruder" yytext)
      end
fun yyAction28 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RN "Schwester" yytext)
      end
fun yyAction29 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RN "Hauptstadt" yytext)
      end
fun yyAction30 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Stadt" yytext)
      end
fun yyAction31 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "gesund"))
fun yyAction32 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "weiß"))
fun yyAction33 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "braun"))
fun yyAction34 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "toll"))
fun yyAction35 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "nett"))
fun yyAction36 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "schön" yytext)
      end
fun yyAction37 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "schöner" yytext)
      end
fun yyAction38 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "älter" yytext)
      end
fun yyAction39 (strm, lastMatch : yymatch) = (yystrm := strm; (P "in"))
fun yyAction40 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IV "arbeiten" yytext)
      end
fun yyAction41 (strm, lastMatch : yymatch) = (yystrm := strm; (TV "kennen"))
fun yyAction42 (strm, lastMatch : yymatch) = (yystrm := strm; (TV "lieben"))
fun yyAction43 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "schöner" yytext)
      end
fun yyAction44 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "älter" yytext)
      end
fun yyAction45 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "größer" yytext)
      end
fun yyAction46 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IAcomp "kleiner" yytext)
      end
fun yyAction47 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "älter" yytext)
      end
fun yyAction48 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "größer" yytext)
      end
fun yyAction49 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (IA "kleiner" yytext)
      end
fun yyAction50 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Ameise" yytext)
      end
fun yyAction51 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Hund" yytext)
      end
fun yyAction52 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Elephant" yytext)
      end
fun yyAction53 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CN "Tier" yytext)
      end
fun yyAction54 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        (error ("ignoring illegal character " ^ yytext,
                      !line,!line); lex())
      end
val yyactTable = Vector.fromList([yyAction0, yyAction1, yyAction2, yyAction3,
  yyAction4, yyAction5, yyAction6, yyAction7, yyAction8, yyAction9, yyAction10,
  yyAction11, yyAction12, yyAction13, yyAction14, yyAction15, yyAction16,
  yyAction17, yyAction18, yyAction19, yyAction20, yyAction21, yyAction22,
  yyAction23, yyAction24, yyAction25, yyAction26, yyAction27, yyAction28,
  yyAction29, yyAction30, yyAction31, yyAction32, yyAction33, yyAction34,
  yyAction35, yyAction36, yyAction37, yyAction38, yyAction39, yyAction40,
  yyAction41, yyAction42, yyAction43, yyAction44, yyAction45, yyAction46,
  yyAction47, yyAction48, yyAction49, yyAction50, yyAction51, yyAction52,
  yyAction53, yyAction54])
in
  if yyInput.eof(!(yystrm))
    then UserDeclarations.eof(yyarg)
    else (case (!(yyss))
       of INITIAL => yygo yyactTable (0, !(yystrm), yyNO_MATCH)
      (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
